pub enum SwapAmount {
Invoice(Amount),
Vhtlc(Amount),
}Expand description
The amount to be shared with Boltz when creating a reverse submarine swap.
Variants
Invoice(Amount)
Use this value if you need to set the value to be sent by the payer on Lightning.
Vhtlc(Amount)
Use this value if you need to set the value to be received by the payee on Arkade.
Implementations