pub struct StaticKeyProvider { /* private fields */ }Expand description
A simple key provider that uses a static keypair
This is the simplest implementation and is backward compatible with the original single-keypair design.
Implementations