pub struct ContractRestoreReport {
pub gap_limit: u32,
pub scanned_from: Option<u32>,
pub scanned_to_exclusive: Option<u32>,
pub scanned_keys: u32,
pub discovered_key_indexes: Vec<u32>,
pub last_used_key_index: Option<u32>,
pub next_key_index: Option<u32>,
pub offchain_contracts: u32,
pub boarding_contracts: u32,
pub inserted_contracts: u32,
pub known_contracts: u32,
pub entries: Vec<ContractRestoreEntry>,
}Expand description
Summary returned by Client::restore_contracts.
Fields
gap_limit: u32Gap limit used for this scan.
scanned_from: Option<u32>First derived key index that was probed, if any.
scanned_to_exclusive: Option<u32>One past the last derived key index that was probed, if any.
scanned_keys: u32Derived key indexes that were probed.
discovered_key_indexes: Vec<u32>Key indexes where at least one contract had activity.
last_used_key_index: Option<u32>Highest discovered key index, if any.
next_key_index: Option<u32>Suggested next receive key index, if any.
offchain_contracts: u32Offchain default/delegate contracts with VTXO activity.
boarding_contracts: u32Boarding contracts with on-chain UTXO activity.
inserted_contracts: u32Contracts that were not already in the store.
known_contracts: u32Discovered contracts that were already present in the store.
entries: Vec<ContractRestoreEntry>Per-contract discovery details for caller UX.
Implementations
Sourceimpl ContractRestoreReport
impl ContractRestoreReport
pub fn discovered_keys(&self) -> u32
pub fn discovered_contracts(&self) -> u32