OfflineClient

Struct OfflineClient 

pub struct OfflineClient<B, W, S> { /* private fields */ }
A client to interact with Ark Server

Example


struct MyBlockchain {}

struct MyWallet {}

// Initialize the client with a static keypair
async fn init_client_with_keypair() -> Result<Client<MyBlockchain, MyWallet, InMemorySwapStorage>, ark_client::Error> {
    // Create a keypair for signing transactions
    let secp = bitcoin::key::Secp256k1::new();
    let secret_key = SecretKey::from_str("your_private_key_here").unwrap();
    let keypair = Keypair::from_secret_key(&secp, &secret_key);

    // Initialize blockchain and wallet implementations
    let blockchain = Arc::new(MyBlockchain::new("https://esplora.example.com"));
    let wallet = Arc::new(MyWallet {});

    let config = OfflineClientConfig {
        ark_server_url: "https://ark-server.example.com".to_string(),
        boltz_url: "http://boltz.example.com".to_string(),
        ..Default::default()
    };

    let offline_client = OfflineClient::with_keypair(
        config,
        keypair,
        blockchain,
        wallet,
        Arc::new(InMemorySwapStorage::default()),
    );

    // Connect to the Ark server and get server info
    let client = offline_client.connect().await?;

    Ok(client)
}

// Initialize the client with a BIP32 HD wallet
async fn init_client_with_bip32() -> Result<Client<MyBlockchain, MyWallet, InMemorySwapStorage>, ark_client::Error> {
    // Create a BIP32 master key and derivation path
    let master_key = Xpriv::from_str("xprv...").unwrap();
    let derivation_path = DerivationPath::from_str("m/84'/0'/0'/0/0").unwrap();

    // Initialize blockchain and wallet implementations
    let blockchain = Arc::new(MyBlockchain::new("https://esplora.example.com"));
    let wallet = Arc::new(MyWallet {});

    let config = OfflineClientConfig {
        ark_server_url: "https://ark-server.example.com".to_string(),
        boltz_url: "http://boltz.example.com".to_string(),
        ..Default::default()
    };

    let offline_client = OfflineClient::with_bip32(
        config,
        master_key,
        Some(derivation_path),
        blockchain,
        wallet,
        Arc::new(InMemorySwapStorage::default()),
    );

    // Connect to the Ark server and get server info
    let client = offline_client.connect().await?;

    Ok(client)
}

Implementations

Source

impl<B, W, S> OfflineClient<B, W, S>
where B: Blockchain, W: OnchainWallet, S: SwapStorage + 'static,

pub fn with_key_provider( config: OfflineClientConfig, key_provider: Arc<dyn KeyProvider>, blockchain: Arc<B>, wallet: Arc<W>, swap_storage: Arc<S>, ) -> Self

Create a new offline client with a generic key provider.

pub fn with_discoverable_key_provider<P>( config: OfflineClientConfig, key_provider: Arc<P>, blockchain: Arc<B>, wallet: Arc<W>, swap_storage: Arc<S>, ) -> Self
where P: DiscoverableKeyProvider + 'static,

Create a new offline client with a discoverable key provider.

pub fn with_keypair( config: OfflineClientConfig, kp: Keypair, blockchain: Arc<B>, wallet: Arc<W>, swap_storage: Arc<S>, ) -> Self

Create a new offline client with a static keypair.

pub fn with_bip32( config: OfflineClientConfig, xpriv: Xpriv, path: Option<DerivationPath>, blockchain: Arc<B>, wallet: Arc<W>, swap_storage: Arc<S>, ) -> Self

Create a new offline client with an Xpriv.

pub fn with_contract_store(self, store: Box<dyn ContractStore>) -> Self

Use a custom contract store for the connected client.

If unset, the client uses an in-memory contract store.

pub fn delegator_pk(&self) -> Option<XOnlyPublicKey>

Returns the currently configured delegator pubkey, if any.

pub fn boltz_referral_id(&self) -> Option<&str>

Returns the Boltz referral ID sent with all swap creation requests, if any.

pub async fn connect(self) -> Result<Client<B, W, S>, Error>

Connects to the Ark server and retrieves server information.

Errors

Returns an error if the connection fails or times out.

pub async fn connect_with_retries( self, max_retries: usize, ) -> Result<Client<B, W, S>, Error>

Connects to the Ark server and retrieves server information.

If it encounters errors, it will retry max_retries.

Errors

Returns an error if the connection fails or times out.