Re-exports
pub use error::Error;pub use key_provider::Bip32KeyProvider;pub use key_provider::KeyProvider;pub use key_provider::StaticKeyProvider;pub use swap_storage::InMemorySwapStorage;pub use swap_storage::SwapStorage;pub use lightning_invoice;
Modules
- error
- key_
provider - swap_
storage - Swap Storage
- vtxo_
watcher - Background VTXO watcher that auto-delegates and auto-renews VTXOs.
- wallet
Structs
- Address
Vtxos - Chain
Swap Data - Data for a pending chain swap (ARK ↔ BTC).
- Chain
Swap Result - Result of creating a chain swap.
- Client
- A client to interact with Ark server
- Issue
Asset Result - Result of an asset issuance.
- OffChain
Balance - Offline
Client - A client to interact with Ark Server
- Pending
Vhtlc Spend Tx - A pending (submitted but not finalized) VHTLC spend transaction.
- Reverse
Swap Data - Data related to a reverse submarine swap.
- Spend
Status - Submarine
Swap Data - Data related to a submarine swap.
- Swap
Status Info - Status information for a Boltz swap.
- Timeout
Block Heights - TxStatus
Enums
- Chain
Swap Amount - The amount specification for a chain swap.
- Chain
Swap Direction - Direction of a chain swap.
- Pending
Vhtlc Spend Type - The type of VHTLC spend that was submitted but not yet finalized.
- Swap
Amount - The amount to be shared with Boltz when creating a reverse submarine swap.
- Swap
Status - All possible states of a Boltz swap.
- Swap
Type - The type of a Boltz swap.
Constants
- DEFAULT_
BOLTZ_ REFERRAL_ ID - Default Boltz
referralIdsent with swap creation requests when the caller does not provide one. Identifies traffic originating from this SDK. - DEFAULT_
GAP_ LIMIT - Default gap limit for BIP44-style key discovery