Crate ark_client

Crate ark_client 

Re-exports

pub use error::Error;
pub use key_provider::Bip32KeyProvider;
pub use key_provider::KeyProvider;
pub use key_provider::StaticKeyProvider;
pub use swap_storage::InMemorySwapStorage;
pub use swap_storage::SwapStorage;
pub use lightning_invoice;

Modules

error
key_provider
swap_storage
Swap Storage
vtxo_watcher
Background VTXO watcher that auto-delegates and auto-renews VTXOs.
wallet

Structs

AddressVtxos
ChainSwapData
Data for a pending chain swap (ARK ↔ BTC).
ChainSwapResult
Result of creating a chain swap.
Client
A client to interact with Ark server
IssueAssetResult
Result of an asset issuance.
OffChainBalance
OfflineClient
A client to interact with Ark Server
PendingVhtlcSpendTx
A pending (submitted but not finalized) VHTLC spend transaction.
ReverseSwapData
Data related to a reverse submarine swap.
SpendStatus
SubmarineSwapData
Data related to a submarine swap.
SwapStatusInfo
Status information for a Boltz swap.
TimeoutBlockHeights
TxStatus

Enums

ChainSwapAmount
The amount specification for a chain swap.
ChainSwapDirection
Direction of a chain swap.
PendingVhtlcSpendType
The type of VHTLC spend that was submitted but not yet finalized.
SwapAmount
The amount to be shared with Boltz when creating a reverse submarine swap.
SwapStatus
All possible states of a Boltz swap.
SwapType
The type of a Boltz swap.

Constants

DEFAULT_GAP_LIMIT
Default gap limit for BIP44-style key discovery

Traits

Blockchain